@@ -120,7 +120,7 @@ def shift(subs, ms):
 def strip_html(subs):
     for sub in subs:
         for i in range(0, len(sub.content)):
-            sub.content[i] = re.sub('<.+>', '', sub.content[i])
+            sub.content[i] = re.sub('<.+?>', '', sub.content[i])
 
 
 def process_file(args, file, expressions):
@@ -211,6 +211,7 @@ def read_expressions(args):
 
 def main():
     parser = argparse.ArgumentParser(
+        prog='fsub',
         description='Fix, edit and clean SubRip (.srt) files.',
         add_help=True
     )
